@@ -18,8 +18,5 @@
 #include <sys/wait.h>
 #endif
 
-#if !defined(_MSC_VER) && !defined(__MINGW32__) && !defined(_WIN32)
-extern int execvpe(char *name, char *const argv[], char **envp);
 extern void pPrPr_disableITimers (void);
-#endif
 
